@@ -37,34 +37,28 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#include <gio/gio.h>
 
-#include "egg-debug.h"
 #include "gpm-idletime.h"
 
 #include "gpm-idle.h"
-#include "gpm-load.h"
-#include "gpm-session.h"
 
 #define GPM_IDLE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_IDLE, GpmIdlePrivate))
 
-/* Sets the idle percent limit, i.e. how hard the computer can work
-   while considered "at idle" */
-#define GPM_IDLE_CPU_LIMIT			5
 #define	GPM_IDLE_IDLETIME_ID			1
 
 struct GpmIdlePrivate
 {
-	GpmIdletime	*idletime;
-	GpmLoad		*load;
-	GpmSession	*session;
-	GpmIdleMode	 mode;
-	guint		 timeout_dim;		/* in seconds */
-	guint		 timeout_blank;		/* in seconds */
-	guint		 timeout_sleep;		/* in seconds */
-	guint		 timeout_blank_id;
-	guint		 timeout_sleep_id;
-	gboolean	 x_idle;
-	gboolean	 check_type_cpu;
+	GpmIdletime		*idletime;
+	GDBusProxy		*proxy;
+	GDBusProxy		*proxy_presence;
+	GpmIdleMode		 mode;
+	guint			 timeout_dim;		/* in seconds */
+	guint			 timeout_blank;		/* in seconds */
+	guint			 timeout_sleep;		/* in seconds */
+	guint			 timeout_blank_id;
+	guint			 timeout_sleep_id;
+	gboolean		 x_idle;
 };
 
 enum {
@@ -105,24 +99,11 @@ gpm_idle_set_mode (GpmIdle *idle, GpmIdleMode mode)
 
 	if (mode != idle->priv->mode) {
 		idle->priv->mode = mode;
-		egg_debug ("Doing a state transition: %s", gpm_idle_mode_to_string (mode));
+		g_debug ("Doing a state transition: %s", gpm_idle_mode_to_string (mode));
 		g_signal_emit (idle, signals [IDLE_CHANGED], 0, mode);
 	}
 }
 
-/**
- * gpm_idle_set_check_cpu:
- * @check_type_cpu: If we should check the CPU before mode becomes
- *		    GPM_IDLE_MODE_SLEEP and the event is done.
- **/
-void
-gpm_idle_set_check_cpu (GpmIdle *idle, gboolean check_type_cpu)
-{
-	g_return_if_fail (GPM_IS_IDLE (idle));
-	egg_debug ("Setting the CPU load check to %i", check_type_cpu);
-	idle->priv->check_type_cpu = check_type_cpu;
-}
-
 /**
  * gpm_idle_get_mode:
  * Return value: The current mode, e.g. GPM_IDLE_MODE_SLEEP
@@ -140,7 +121,7 @@ static gboolean
 gpm_idle_blank_cb (GpmIdle *idle)
 {
 	if (idle->priv->mode > GPM_IDLE_MODE_BLANK) {
-		egg_debug ("ignoring current mode %s", gpm_idle_mode_to_string (idle->priv->mode));
+		g_debug ("ignoring current mode %s", gpm_idle_mode_to_string (idle->priv->mode));
 		return FALSE;
 	}
 	gpm_idle_set_mode (idle, GPM_IDLE_MODE_BLANK);
@@ -153,24 +134,79 @@ gpm_idle_blank_cb (GpmIdle *idle)
 static gboolean
 gpm_idle_sleep_cb (GpmIdle *idle)
 {
-	gdouble load;
-	gboolean ret = FALSE;
-
-	/* get our computed load value */
-	if (idle->priv->check_type_cpu) {
-		load = gpm_load_get_current (idle->priv->load);
-		if (load > GPM_IDLE_CPU_LIMIT) {
-			/* check if system is "idle" enough */
-			egg_debug ("Detected that the CPU is busy");
-			ret = TRUE;
-			goto out;
-		}
-	}
 	gpm_idle_set_mode (idle, GPM_IDLE_MODE_SLEEP);
+	return FALSE;
+}
+
+typedef enum {
+	GPM_IDLE_STATUS_ENUM_AVAILABLE = 0,
+	GPM_IDLE_STATUS_ENUM_INVISIBLE,
+	GPM_IDLE_STATUS_ENUM_BUSY,
+	GPM_IDLE_STATUS_ENUM_IDLE,
+	GPM_IDLE_STATUS_ENUM_UNKNOWN
+} GpmIdleStatusEnum;
+
+/**
+ * gpm_idle_is_session_idle:
+ **/
+static gboolean
+gpm_idle_is_session_idle (GpmIdle *idle)
+{
+	gboolean ret = FALSE;
+	GVariant *result;
+	guint status;
+
+	/* get the session status */
+	result = g_dbus_proxy_get_cached_property (idle->priv->proxy_presence, "status");
+	if (result == NULL)
+		goto out;
+
+	g_variant_get (result, "u", &status);
+	ret = (status == GPM_IDLE_STATUS_ENUM_IDLE);
+	g_variant_unref (result);
 out:
 	return ret;
 }
 
+typedef enum {
+	GPM_IDLE_INHIBIT_MASK_LOGOUT = 1,
+	GPM_IDLE_INHIBIT_MASK_SWITCH = 2,
+	GPM_IDLE_INHIBIT_MASK_SUSPEND = 4,
+	GPM_IDLE_INHIBIT_MASK_IDLE = 8
+} GpmIdleInhibitMask;
+
+/**
+ * gpm_idle_is_session_inhibited:
+ **/
+static gboolean
+gpm_idle_is_session_inhibited (GpmIdle *idle, guint mask)
+{
+	gboolean ret = FALSE;
+	GVariant *retval = NULL;
+	GError *error = NULL;
+
+	retval = g_dbus_proxy_call_sync (idle->priv->proxy,
+					 "IsInhibited",
+					 g_variant_new ("(u)",
+							mask),
+					 G_DBUS_CALL_FLAGS_NONE,
+					 -1, NULL,
+					 &error);
+	if (retval == NULL) {
+		/* abort as the DBUS method failed */
+		g_warning ("IsInhibited failed: %s", error->message);
+		g_error_free (error);
+		goto out;
+	}
+
+	/* success */
+	g_variant_get (retval, "(b)", &ret);
+out:
+	if (retval != NULL)
+		g_variant_unref (retval);
+	return ret;
+}
+
 /**
  * gpm_idle_evaluate:
  **/
@@ -181,15 +217,10 @@ gpm_idle_evaluate (GpmIdle *idle)
 	gboolean is_idle_inhibited;
 	gboolean is_suspend_inhibited;
 
-	is_idle = gpm_session_get_idle (idle->priv->session);
-	is_idle_inhibited = gpm_session_get_idle_inhibited (idle->priv->session);
-	is_suspend_inhibited = gpm_session_get_suspend_inhibited (idle->priv->session);
-	egg_debug ("session_idle=%i, idle_inhibited=%i, suspend_inhibited=%i, x_idle=%i", is_idle, is_idle_inhibited, is_suspend_inhibited, idle->priv->x_idle);
-
 	/* check we are really idle */
 	if (!idle->priv->x_idle) {
 		gpm_idle_set_mode (idle, GPM_IDLE_MODE_NORMAL);
-		egg_debug ("X not idle");
+		g_debug ("X not idle");
 		if (idle->priv->timeout_blank_id != 0) {
 			g_source_remove (idle->priv->timeout_blank_id);
 			idle->priv->timeout_blank_id = 0;
@@ -202,8 +233,9 @@ gpm_idle_evaluate (GpmIdle *idle)
 	}
 
 	/* are we inhibited from going idle */
+	is_idle_inhibited = gpm_idle_is_session_inhibited (idle, GPM_IDLE_INHIBIT_MASK_IDLE);
 	if (is_idle_inhibited) {
-		egg_debug ("inhibited, so using normal state");
+		g_debug ("inhibited, so using normal state");
 		gpm_idle_set_mode (idle, GPM_IDLE_MODE_NORMAL);
 		if (idle->priv->timeout_blank_id != 0) {
 			g_source_remove (idle->priv->timeout_blank_id);
@@ -218,7 +250,7 @@ gpm_idle_evaluate (GpmIdle *idle)
 
 	/* normal to dim */
 	if (idle->priv->mode == GPM_IDLE_MODE_NORMAL) {
-		egg_debug ("normal to dim");
+		g_debug ("normal to dim");
 		gpm_idle_set_mode (idle, GPM_IDLE_MODE_DIM);
 	}
 
@@ -226,31 +258,29 @@ gpm_idle_evaluate (GpmIdle *idle)
 	 * but only if we actually want to blank. */
 	if (idle->priv->timeout_blank_id == 0 &&
 	    idle->priv->timeout_blank != 0) {
-		egg_debug ("setting up blank callback for %is", idle->priv->timeout_blank);
+		g_debug ("setting up blank callback for %is", idle->priv->timeout_blank);
 		idle->priv->timeout_blank_id = g_timeout_add_seconds (idle->priv->timeout_blank,
 								      (GSourceFunc) gpm_idle_blank_cb, idle);
-#if GLIB_CHECK_VERSION(2,25,8)
 		g_source_set_name_by_id (idle->priv->timeout_blank_id, "[GpmIdle] blank");
-#endif
 	}
 
 	/* are we inhibited from sleeping */
+	is_idle = gpm_idle_is_session_idle (idle);
+	is_suspend_inhibited = gpm_idle_is_session_inhibited (idle, GPM_IDLE_INHIBIT_MASK_SUSPEND);
 	if (is_suspend_inhibited) {
-		egg_debug ("suspend inhibited");
+		g_debug ("suspend inhibited");
 		if (idle->priv->timeout_sleep_id != 0) {
 			g_source_remove (idle->priv->timeout_sleep_id);
 			idle->priv->timeout_sleep_id = 0;
 		}
 	} else if (is_idle) {
-	/* only do the sleep timeout when the session is idle and we aren't inhibited from sleeping */
+		/* only do the sleep timeout when the session is idle and we aren't inhibited from sleeping */
 		if (idle->priv->timeout_sleep_id == 0 &&
 		    idle->priv->timeout_sleep != 0) {
-			egg_debug ("setting up sleep callback %is", idle->priv->timeout_sleep);
+			g_debug ("setting up sleep callback %is", idle->priv->timeout_sleep);
 			idle->priv->timeout_sleep_id = g_timeout_add_seconds (idle->priv->timeout_sleep,
 									      (GSourceFunc) gpm_idle_sleep_cb, idle);
-#if GLIB_CHECK_VERSION(2,25,8)
 			g_source_set_name_by_id (idle->priv->timeout_sleep_id, "[GpmIdle] sleep");
-#endif
 		}
 	}
 out:
@@ -300,11 +330,11 @@ gpm_idle_set_timeout_dim (GpmIdle *idle, guint timeout)
 
 	idle_time_in_msec = gpm_idletime_get_time (idle->priv->idletime);
 	timeout_adjusted  = gpm_idle_adjust_timeout_dim (idle_time_in_msec / 1000, timeout);
-	egg_debug ("Current idle time=%lldms, timeout was %us, becomes %us after adjustment",
+	g_debug ("Current idle time=%lldms, timeout was %us, becomes %us after adjustment",
 		   (long long int)idle_time_in_msec, timeout, timeout_adjusted);
 	timeout = timeout_adjusted;
 
-	egg_debug ("Setting dim idle timeout: %ds", timeout);
+	g_debug ("Setting dim idle timeout: %ds", timeout);
 	if (idle->priv->timeout_dim != timeout) {
 		idle->priv->timeout_dim = timeout;
 
@@ -325,7 +355,7 @@ gpm_idle_set_timeout_blank (GpmIdle *idle, guint timeout)
 {
 	g_return_val_if_fail (GPM_IS_IDLE (idle), FALSE);
 
-	egg_debug ("Setting blank idle timeout: %ds", timeout);
+	g_debug ("Setting blank idle timeout: %ds", timeout);
 	if (idle->priv->timeout_blank != timeout) {
 		idle->priv->timeout_blank = timeout;
 		gpm_idle_evaluate (idle);
@@ -342,7 +372,7 @@ gpm_idle_set_timeout_sleep (GpmIdle *idle, guint timeout)
 {
 	g_return_val_if_fail (GPM_IS_IDLE (idle), FALSE);
 
-	egg_debug ("Setting sleep idle timeout: %ds", timeout);
+	g_debug ("Setting sleep idle timeout: %ds", timeout);
 	if (idle->priv->timeout_sleep != timeout) {
 		idle->priv->timeout_sleep = timeout;
 		gpm_idle_evaluate (idle);
@@ -350,29 +380,6 @@ gpm_idle_set_timeout_sleep (GpmIdle *idle, guint timeout)
 	return TRUE;
 }
 
-/**
- * gpm_idle_session_idle_changed_cb:
- * @is_idle: If the session is idle
- *
- * The SessionIdleChanged callback from gnome-session.
- **/
-static void
-gpm_idle_session_idle_changed_cb (GpmSession *session, gboolean is_idle, GpmIdle *idle)
-{
-	egg_debug ("Received gnome session idle changed: %i", is_idle);
-	gpm_idle_evaluate (idle);
-}
-
-/**
- * gpm_idle_session_inhibited_changed_cb:
- **/
-static void
-gpm_idle_session_inhibited_changed_cb (GpmSession *session, gboolean is_idle_inhibited, gboolean is_suspend_inhibited, GpmIdle *idle)
-{
-	egg_debug ("Received gnome session inhibited changed: idle=(%i), suspend=(%i)", is_idle_inhibited, is_suspend_inhibited);
-	gpm_idle_evaluate (idle);
-}
-
 /**
  * gpm_idle_idletime_alarm_expired_cb:
  *
@@ -381,7 +388,7 @@ gpm_idle_session_inhibited_changed_cb (GpmSession *session, gboolean is_idle_inh
 static void
 gpm_idle_idletime_alarm_expired_cb (GpmIdletime *idletime, guint alarm_id, GpmIdle *idle)
 {
-	egg_debug ("idletime alarm: %i", alarm_id);
+	g_debug ("idletime alarm: %i", alarm_id);
 
 	/* set again */
 	idle->priv->x_idle = TRUE;
@@ -396,12 +403,38 @@ gpm_idle_idletime_alarm_expired_cb (GpmIdletime *idletime, guint alarm_id, GpmId
 static void
 gpm_idle_idletime_reset_cb (GpmIdletime *idletime, GpmIdle *idle)
 {
-	egg_debug ("idletime reset");
+	g_debug ("idletime reset");
 
 	idle->priv->x_idle = FALSE;
 	gpm_idle_evaluate (idle);
 }
 
+/**
+ * gpm_idle_dbus_signal_cb:
+ **/
+static void
+gpm_idle_dbus_signal_cb (GDBusProxy *proxy, const gchar *sender_name, const gchar *signal_name, GVariant *parameters, gpointer user_data)
+{
+	GpmIdle *idle = GPM_IDLE (user_data);
+
+	if (g_strcmp0 (signal_name, "InhibitorAdded") == 0 ||
+	    g_strcmp0 (signal_name, "InhibitorRemoved") == 0) {
+		g_debug ("Received gnome session inhibitor change");
+		gpm_idle_evaluate (idle);
+		return;
+	}
+	if (g_strcmp0 (signal_name, "StatusChanged") == 0) {
+                guint status;
+
+                g_variant_get (parameters, "(u)", &status);
+                g_dbus_proxy_set_cached_property (proxy, "status",
+                                                  g_variant_new ("u", status));
+		g_debug ("Received gnome session status change");
+		gpm_idle_evaluate (idle);
+		return;
+	}
+}
+
 /**
  * gpm_idle_finalize:
  * @object: This class instance
@@ -423,8 +456,10 @@ gpm_idle_finalize (GObject *object)
 	if (idle->priv->timeout_sleep_id != 0)
 		g_source_remove (idle->priv->timeout_sleep_id);
 
-	g_object_unref (idle->priv->load);
-	g_object_unref (idle->priv->session);
+	if (idle->priv->proxy != NULL)
+		g_object_unref (idle->priv->proxy);
+	if (idle->priv->proxy_presence != NULL)
+		g_object_unref (idle->priv->proxy_presence);
 
 	gpm_idletime_alarm_remove (idle->priv->idletime, GPM_IDLE_IDLETIME_ID);
 	g_object_unref (idle->priv->idletime);
@@ -464,6 +499,9 @@ gpm_idle_class_init (GpmIdleClass *klass)
 static void
 gpm_idle_init (GpmIdle *idle)
 {
+	GDBusConnection *connection;
+	GError *error = NULL;
+
 	idle->priv = GPM_IDLE_GET_PRIVATE (idle);
 
 	idle->priv->timeout_dim = G_MAXUINT;
@@ -472,15 +510,49 @@ gpm_idle_init (GpmIdle *idle)
 	idle->priv->timeout_blank_id = 0;
 	idle->priv->timeout_sleep_id = 0;
 	idle->priv->x_idle = FALSE;
-	idle->priv->load = gpm_load_new ();
-	idle->priv->session = gpm_session_new ();
-	g_signal_connect (idle->priv->session, "idle-changed", G_CALLBACK (gpm_idle_session_idle_changed_cb), idle);
-	g_signal_connect (idle->priv->session, "inhibited-changed", G_CALLBACK (gpm_idle_session_inhibited_changed_cb), idle);
 
 	idle->priv->idletime = gpm_idletime_new ();
 	g_signal_connect (idle->priv->idletime, "reset", G_CALLBACK (gpm_idle_idletime_reset_cb), idle);
 	g_signal_connect (idle->priv->idletime, "alarm-expired", G_CALLBACK (gpm_idle_idletime_alarm_expired_cb), idle);
 
+	/* get connection */
+	connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
+	if (connection == NULL) {
+		g_warning ("Failed to get session connection: %s", error->message);
+		g_error_free (error);
+		return;
+	}
+
+	/* get org.gnome.Session main interface */
+	idle->priv->proxy =
+		g_dbus_proxy_new_sync (connection,
+			0, NULL,
+			"org.gnome.SessionManager",
+			"/org/gnome/SessionManager",
+			"org.gnome.SessionManager",
+			NULL, &error);
+	if (idle->priv->proxy == NULL) {
+		g_warning ("Cannot connect to session manager: %s", error->message);
+		g_error_free (error);
+		return;
+	}
+	g_signal_connect (idle->priv->proxy, "g-signal", G_CALLBACK (gpm_idle_dbus_signal_cb), idle);
+
+	/* get org.gnome.Session.Presence interface */
+	idle->priv->proxy_presence =
+		g_dbus_proxy_new_sync (connection,
+			0, NULL,
+			"org.gnome.SessionManager",
+			"/org/gnome/SessionManager/Presence",
+			"org.gnome.SessionManager.Presence",
+			NULL, &error);
+	if (idle->priv->proxy_presence == NULL) {
+		g_warning ("Cannot connect to session manager: %s", error->message);
+		g_error_free (error);
+		return;
+	}
+	g_signal_connect (idle->priv->proxy_presence, "g-signal", G_CALLBACK (gpm_idle_dbus_signal_cb), idle);
+
 	gpm_idle_evaluate (idle);
 }
 
