@@ -26,9 +26,6 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
-#include "gpm-screensaver.h"
-#include "gpm-dpms.h"
-#include "gpm-phone.h"
 #include "gpm-idle.h"
 #include "gpm-common.h"
 #include "gpm-idletime.h"
@@ -101,54 +98,6 @@ _g_test_loop_quit (void)
 
 /**********************************************************************/
 
-static void
-gpm_test_dpms_func (void)
-{
-	GpmDpms *dpms;
-	gboolean ret;
-	GError *error = NULL;
-
-	dpms = gpm_dpms_new ();
-	g_assert (dpms != NULL);
-
-	/* set on */
-	ret = gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_ON, &error);
-	g_assert_no_error (error);
-	g_assert (ret);
-
-	g_usleep (2*1000*1000);
-
-	/* set STANDBY */
-	ret = gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_STANDBY, &error);
-	g_assert_no_error (error);
-	g_assert (ret);
-
-	g_usleep (2*1000*1000);
-
-	/* set SUSPEND */
-	ret = gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_SUSPEND, &error);
-	g_assert_no_error (error);
-	g_assert (ret);
-
-	g_usleep (2*1000*1000);
-
-	/* set OFF */
-	ret = gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_OFF, &error);
-	g_assert_no_error (error);
-	g_assert (ret);
-
-	g_usleep (2*1000*1000);
-
-	/* set on */
-	ret = gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_ON, &error);
-	g_assert_no_error (error);
-	g_assert (ret);
-
-	g_usleep (2*1000*1000);
-
-	g_object_unref (dpms);
-}
-
 static GpmIdleMode _mode = 0;
 
 static void
@@ -163,8 +112,8 @@ static void
 gpm_test_idle_func (void)
 {
 	GpmIdle *idle;
-	gboolean ret;
-	GpmDpms *dpms;
+//	gboolean ret;
+//	GpmDpms *dpms;
 
 	idle = gpm_idle_new ();
 	g_assert (idle != NULL);
@@ -223,9 +172,9 @@ gpm_test_idle_func (void)
 	g_assert_cmpint (gpm_idle_get_mode (idle), ==, GPM_IDLE_MODE_BLANK);
 
 	/* set dpms off */
-	dpms = gpm_dpms_new ();
-	ret = gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_OFF, NULL);
-	g_assert (ret);
+//	dpms = gpm_dpms_new ();
+//	ret = gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_OFF, NULL);
+//	g_assert (ret);
 
 	/* wait for normal event to be suppressed */
 //	g_timeout_add (2000, (GSourceFunc) gpm_test_idle_func_delay_cb, NULL);
@@ -234,100 +183,10 @@ gpm_test_idle_func (void)
 	/* check current mode */
 	g_assert_cmpint (gpm_idle_get_mode (idle), ==, GPM_IDLE_MODE_BLANK);
 
-	gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_ON, NULL);
+//	gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_ON, NULL);
 
 	g_object_unref (idle);
-	g_object_unref (dpms);
-}
-
-static gboolean _test_got_refresh = FALSE;
-
-static void
-gpm_test_phone_device_refresh_cb (GpmPhone *phone, guint idx, gpointer *data)
-{
-	g_debug ("idx refresh = %i", idx);
-	if (idx == 0 && GPOINTER_TO_UINT (data) == 44)
-		_test_got_refresh = TRUE;
-}
-
-static void
-gpm_test_phone_func (void)
-{
-	GpmPhone *phone;
-	guint value;
-	gboolean ret;
-
-	/* make sure we get a non null phone */
-	phone = gpm_phone_new ();
-	g_assert (phone != NULL);
-
-	/* connect signals */
-	g_signal_connect (phone, "device-refresh",
-			  G_CALLBACK (gpm_test_phone_device_refresh_cb), GUINT_TO_POINTER(44));
-
-	/* coldplug the data */
-	ret = gpm_phone_coldplug (phone);
-	g_assert (ret);
-
-	_g_test_loop_run_with_timeout (500);
-
-	/* got refresh */
-	g_assert (_test_got_refresh);
-
-	/* check the connected phones */
-	value = gpm_phone_get_num_batteries (phone);
-	g_assert_cmpint (value, ==, 1);
-
-	/* check the present value */
-	ret = gpm_phone_get_present (phone, 0);
-	g_assert (ret);
-
-	/* check the percentage */
-	value = gpm_phone_get_percentage (phone, 0);
-	g_assert_cmpint (value, !=, 0);
-
-	/* check the ac value */
-	ret = gpm_phone_get_on_ac (phone, 0);
-	g_assert (ret);
-//out:
-	g_object_unref (phone);
-}
-
-#if 0
-static void
-gpm_test_screensaver_func_auth_request_cb (GpmScreensaver *screensaver, gboolean auth, gpointer user_data)
-{
-	g_debug ("auth request = %i", auth);
-	test_got_request = auth;
-
-	_g_test_loop_quit ();
-}
-#endif
-
-static void
-gpm_test_screensaver_func (void)
-{
-	GpmScreensaver *screensaver;
-//	guint value;
-	gboolean ret;
-
-	screensaver = gpm_screensaver_new ();
-	g_assert (screensaver != NULL);
-
-#if 0
-	/* connect signals */
-	g_signal_connect (screensaver, "auth-request",
-			  G_CALLBACK (gpm_test_screensaver_func_auth_request_cb), NULL);
-#endif
-	/* lock */
-	ret = gpm_screensaver_lock (screensaver);
-	g_assert (ret);
-
-	/* poke */
-	ret = gpm_screensaver_poke (screensaver);
-	g_assert (ret);
-
-	g_object_unref (screensaver);
+//	g_object_unref (dpms);
 }
 
 static void
@@ -839,9 +698,6 @@ main (int argc, char **argv)
 	g_type_init ();
 	g_test_init (&argc, &argv, NULL);
 
-	/* needed for DPMS checks */
-	gtk_init (&argc, &argv);
-
 	/* tests go here */
 	g_test_add_func ("/power/precision", gpm_test_precision_func);
 	g_test_add_func ("/power/discrete", gpm_test_discrete_func);
@@ -849,10 +705,6 @@ main (int argc, char **argv)
 	g_test_add_func ("/power/array_float", gpm_test_array_float_func);
 	g_test_add_func ("/power/idle", gpm_test_idle_func);
 	g_test_add_func ("/power/idletime", gpm_test_idletime_func);
-	g_test_add_func ("/power/dpms", gpm_test_dpms_func);
-	g_test_add_func ("/power/phone", gpm_test_phone_func);
-//	g_test_add_func ("/power/graph-widget", gpm_graph_widget_test);
-	g_test_add_func ("/power/screensaver", gpm_test_screensaver_func);
 
 	return g_test_run ();
 }
